pub struct DHLPackageItemHistory {
pub events: Option<Vec<DHLPackageItemHistoryEvent>>,
pub current_status: Option<String>,
pub steps: u64,
}Expand description
Parcel history
Fields
events: Option<Vec<DHLPackageItemHistoryEvent>>The parcel may or may not have made a few stops already, this Vec may contain them.
current_status: Option<String>Current state of the parcel
steps: u64Number of steps there are (or should be?) - might as well use events.len() 🤷♀️